# `BioClients.humanbase`

## HumanBase

Client to HumanBase REST API.
Genome-scale Integrated Analysis of gene Networks in Tissues
GIANT has moved to HumanBase (http://hb.flatironinstitute.org/).
GIANT tissue networks integrate 987 genome-scale datasets, encompassing
~38,000 conditions from ~14,000 publications and include both expression and
interaction measurements.

* <https://hb.flatironinstitute.org>
